<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8">
    <title>{% block title %}Snor{% endblock %}</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="description" content="">
    <meta name="author" content="">

    <script src="/static/js/jquery.min.js"></script>
    <script src="/static/js/handlebars.min.js"></script>
    <script src="/static/js/bootstrap.min.js"></script>
    <!-- Le styles -->
    <link href="/static/css/bootstrap.css?V1" rel="stylesheet">
    <style>
body {
  background-color: #f5f5f5;
  padding-top: 60px; /* 60px to make the container go all the way to the bottom of the topbar */
}

.episode_status{
text-transform:capitalize;
}
hr.greybar {
    border-top: 1px solid #E2E2E2;
    color: #B7B7B7;
}

.details {
    border-bottom: 1px solid #E2E2E2;
    color: #B7B7B7;
    margin-bottom: 16px;
    margin-top: 15px;
    padding-bottom: 10px;
}

.white-panel {
    background-color: #FFFFFF;
    border: 1px solid #DADADA;
    border-radius: 6px 6px 6px 6px;
    box-shadow: 0 1px 2px rgba(0, 0, 0, 0.075);
    color: #333333;
    margin-bottom: 40px;
    padding: 35px 45px;
}

.action-menu {
    border: 1px solid #DADADA;
    border-radius: 6px 6px 6px 6px;
    box-shadow: 0 1px 1px rgba(0, 0, 0, 0.05) inset;
    margin-bottom: 20px;
    min-height: 20px;
    padding: 19px;
}

.action-menu li a:link, .action-menu li a:visited{
  color:#333333;
}

.imdb-icon {
  float: right;
}      

.table-data th, .table-data td {
    border-top: none !important;
    line-height: 18px;
    padding: 6px;
    text-align: left;
    vertical-align: top;
}    
.status_downloaded{
  background-color: #DFF0D8 !important;
  color: #468847;
}
.status_skipped{
  background-color: #D9EDF7 !important;
}    

.status_wanted{
  background-color: #FCF8E3 !important;
}    

.form-signin {
    margin: 0 auto 20px;
    max-width: 385px;
}
.form-signin input[type="text"], .form-signin input[type="password"]{
  font-size: 16px;
  height: auto;
  margin-bottom: 15px;
  padding: 7px 9px;
}
  
    </style>

    <!-- HTML5 shim, for IE6-8 support of HTML5 elements -->
    <!--[if lt IE 9]>
      <script src="/static/js/html5shiv.js"></script>
    <![endif]-->

  </head>

  <body>
{% block navbar %}
    <div class="navbar navbar-inverse navbar-fixed-top">
      <div class="navbar-inner">
        <div class="container">
          <button type="button" class="btn btn-navbar" data-toggle="collapse" data-target=".nav-collapse">
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
          </button>
          <a class="brand" href="/">Snor</a>
          <div class="nav-collapse collapse">
            <ul class="nav">
              <li {% if request.path == '/' %}class="active"{% endif %}><a href="/">Home</a></li>
              <li {% if request.path == '/show/add/' %}class="active"{% endif %}><a href="/show/add/">Add show</a></li>
              <li {% if request.path == '/settings/' %}class="active"{% endif %}><a href="/settings/">Settings</a></li>
              {% if session.username %}
              <li><a href="/logout/">Logout</a></li>
              {% endif %}
            </ul>
          </div><!--/.nav-collapse -->
        </div>
      </div>
    </div>
{% endblock %}

    <div class="container">
    {% block container %}
    <div class="row-fluid">
        <div class="span3">
        {% block menu %}{% endblock %}
        </div>
        
        <div class="span9">
        {% block main %}{% endblock %}
        </div>
    </div>      
    {% endblock %}
    </div> <!-- /container -->

    {% block script %}
    {% endblock %}
  </body>
</html>
